# decay

decay is an [open source](https://github.com/pyl1b/decay.git),
MIT licensed library which groups code for managing changes in values 
based on a predefined rule over time.


[![Build Status](https://travis-ci.org/pyl1b/decay.svg?branch=master)](https://travis-ci.org/pyl1b/decay)
[![Documentation Status](https://readthedocs.org/projects/decay/badge/?version=latest)](https://decay.readthedocs.io/en/latest/?badge=latest)


Install
-------

    pip install decay

You can also download/clone the source, in which case you have to:

    git clone https://github.com/pyl1b/decay.git
    python setup.py install
        
To contribute a patch clone the repo, create a new branch, install in
develop mode:
        
    python setup.py develop
